==> ann-0.2.tar.gz: ann-0.2/include/ann_ds_tee.h <==
/***************************************************************************
                          ann_ds_tee.h  -  description
                             -------------------
    begin                : pon kwi 14 2003
    copyright            : (C) 2003 by Bartosz Lis
    email                : bartoszl@ics.p.lodz.pl
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef __ANN_DS_TEE_H
#define __ANN_DS_TEE_H

#include <ann_ds_rec.h>
#include <ann_log.h>

namespace ANN
{

  class DS_tee;
  
  //              //
 // class DS_tee //
//              //

  class DS_tee : public DS_rec
  {
  private:
    DS_tee();

  protected:
    Log  *log;
    char *label;

    void             log_term();
    virtual bool     do_reset();
    virtual void     do_next();
    virtual bool     do_seek(size_t term_pos_);

  public:
    DS_tee(DS &orig_, Log &log_, const char *label_=0);
    virtual ~DS_tee();
  };
  
} // namespace ANN

#endif /* __ANN_DS_TEE_H */

==> ann-0.3.tar.gz: ann-0.3/include/ann_ds_tee.h <==
/***************************************************************************
                          ann_ds_tee.h  -  description
                             -------------------
    begin                : pon kwi 14 2003
    copyright            : (C) 2003 by Bartosz Lis
    email                : bartoszl@ics.p.lodz.pl
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef __ANN_DS_TEE_H
#define __ANN_DS_TEE_H

#include <ann_ds_rec.h>
#include <ann_sink.h>

namespace ANN
{

  class DS_tee;
  
  //              //
 // class DS_tee //
//              //

  class DS_tee : public DS_rec
  {
  private:
    DS_tee();
    DS_tee(const DS_tee &that);

  protected:
    Sink *sink;
    char *label_in;
    char *label_des_out;
    Loc   last;
    bool  active;

    void             log_term();
    virtual bool     do_reset();
    virtual void     do_next();
    virtual bool     do_seek(size_t term_pos_);
    virtual bool     do_locate(const Loc &loc);

  public:
    DS_tee(DS &orig_, Sink &sink_, const char *label_in_=0,
           const char *label_des_out_=0);
    virtual ~DS_tee();
  };
  
} // namespace ANN

#endif /* __ANN_DS_TEE_H */
